Steerage
========

Pluggable storage backends for Python projects.

This project implements the [Repository Pattern][repository] for data
access, using Pydantic 2.0 models for entity composition and
decomposition.

[repository]: https://martinfowler.com/eaaCatalog/repository.html
